@@ -53,6 +53,7 @@
 
 #include "config.h"
 #include "ascd.h"
+#include "faktory_prot.h"
 #include <workman/workman.h>
 
 XpmIcon alphaXPM;
@@ -164,6 +165,9 @@ unsigned int icon_counter = 0;
 unsigned int icon_tracknbr = 0;
 unsigned int but_current = 0;     /* last selected button */
 
+unsigned int panel_stop = 0;      /* autoswitch to this panel on stop/eject */
+unsigned int panel_play = 0;      /* autoswitch to this panel on play */
+
 char th_name[FAK_CMAX];
 char th_author[FAK_CMAX];
 char th_release[FAK_CMAX];
@@ -387,9 +391,13 @@ void create_window(int argc, char **argv)
     XSetCommand(Disp, Win, argv, argc);
     
     XMapWindow(Disp, Win);
+
     
+    if (debug) fprintf(stderr, "-> calling fak_maskset() from create_window()...\n");
     fak_maskset();
+    if (debug) fprintf(stderr, "-> calling fak_redraw() from create_window()...\n");
     fak_redraw();
+    if (debug) fprintf(stderr, "-> Leaving create_window()\n");
 } 
 
 void newtext(char *txt) { 
@@ -475,8 +483,11 @@ void show_db_f() {
 
     if ((theme_select == 0) || (where == DB_PANEL)) {
 
-	/* there is a message to display, we'll wait for the message to
-	   time-out before handling the track title... */
+	/* 
+	   there is a message to display, we'll wait for the message
+	   to time-out before handling the track title... (but only if
+	   there is no separate areas) 
+	*/
 
 	if ((strlen(led_text) > 0) && (where == MSG_PANEL)) return;
 
@@ -490,6 +501,8 @@ void show_db_f() {
 	    red = TRUE;
 	}
 
+	/* warning: avoid weird datas: */
+
         if (track > cur_ntracks - 1) return;
 	if (track < 0) return;
        
@@ -614,7 +627,7 @@ void main_loop()
 			redraw = TRUE;
 			fak_redraw();
 		    } else {
-			if (debug) fprintf(stderr, "** XEVent - expose, not handled, count = %d\n", Event.xexpose.count);
+			if (debug > 1) fprintf(stderr, "** XEVent - expose, not handled, count = %d\n", Event.xexpose.count);
 		    }
 		    break;
 		    
@@ -636,7 +649,7 @@ void main_loop()
 		    exit(0);
 		    break;
 		default:
-		    if (debug) fprintf(stderr, "** XEvent - unknown event type = %d\n", Event.type);
+		    if (debug > 1) fprintf(stderr, "** XEvent - unknown event type = %d\n", Event.type);
 		    break;
 		}
 
@@ -707,22 +720,32 @@ int main(int argc, char *argv[])
 #endif
 
    if (debug) fprintf(stderr, "** creating main window...\n");
-    create_window(argc, argv);
-    wm_cd_status();
+   create_window(argc, argv);
+   if (debug) fprintf(stderr, "** checking CD status...\n");
+   wm_cd_status();
     
     if (cur_cdmode != WM_CDM_EJECTED) {
        if (debug) fprintf(stderr, "** reading CD initial volume...\n");
 	volume = wm_cd_read_initial_volume(max_volume);
+    } else {
+	if (debug) fprintf(stderr, "** CD is ejected: volume ignored.\n");
     }
 
+    if (debug) fprintf(stderr, "** checking autoplay...\n");
     if ((autoplay) && (cur_cdmode == WM_CDM_STOPPED)) {
 	if (cur_track < 1) {
 	    cur_track = 1;
 	    wm_cd_status();
 	}
+       if (debug) fprintf(stderr, "-> autoplay: play command\n");
 	cd_control(PLAY);
+       if (debug) fprintf(stderr, "-> autoplay: checking status\n");
 	wm_cd_status();
+	if (debug) fprintf(stderr, "-> autoplay: redrawing\n");
 	fak_redraw();
+       if (debug) fprintf(stderr, "-> autoplay: done\n");
+    } else {
+       if (debug) fprintf(stderr, "-> no autoplay\n");
     }
 
    if (debug) fprintf(stderr, "** checking current CD volume in database\n");
@@ -732,8 +755,9 @@ int main(int argc, char *argv[])
 	cd_volume(volume, 10, max_volume);
     }
    
-    if (debug) fprintf(stderr, "** Init passed. Entering main loop.\n");
     fak_maskset();
+
+    if (debug) fprintf(stderr, "** Init passed. Entering main loop.\n");
     redraw = TRUE;
     main_loop();
     return 0;
