@@ -131,6 +131,9 @@ extern unsigned int icon_counter;
 extern unsigned int icon_tracknbr;
 extern unsigned int but_current;
 
+extern unsigned int panel_stop;
+extern unsigned int panel_play;
+
 extern char th_name[];
 extern char th_author[];
 extern char th_release[];
