@@ -63,10 +63,12 @@ int fak_parse_line(char *ligne, char *key, char *arguments)
 	while (((ligne[pos] == ' ') || (ligne[pos] == 9)) && (pos < strlen(ligne))) pos++;
 	if (pos < strlen(ligne)) strcpy(arguments, ligne + pos);
 	else strcpy(arguments, "");
+	if (debug > 2) fprintf(stderr,"++ input: [%s]\n   key:   [%s]\n   args:  [%s]\n", ligne, key, arguments);
 	return TRUE;
     } else {
 	strcpy(key, "");
 	strcpy(arguments, "");
+	if (debug > 2) fprintf(stderr,"++ input: [%s]\n   key:   [%s]\n   args:  [%s]\n", ligne, key, arguments);
 	return FALSE;
     }
 }
@@ -142,8 +144,7 @@ void fak_validate_pixmap(char *string, char *name)
 	sprintf(string, "%s/Default/%s", THDIR, name);
 	if (access(string, R_OK) != 0) {
 	    fprintf(stderr, "\nascd: fatal error while loading theme '%s'\n", theme);
-	    fprintf(stderr, "Pixmap file '%s' was not found.\n", name);
-	    fprintf(stderr, "Please check your configuration.\n\n");
+	    fprintf(stderr, "      Pixmap file '%s' was not found.\n\n", name);
 	    exit(1);
 	}
     }
@@ -169,6 +170,8 @@ void fak_init_theme(int upgrade)
 	thdata[i].h = 0;
 	thdata[i].arg = 0;
 	thdata[i].icon = FALSE;
+	thdata[i].ox = 0;
+	thdata[i].oy = 0;
 
 	if (strcmp(thdata[i].xpm_file, "") != 0) {
 	    strcpy(thdata[i].xpm_file, "");
@@ -191,6 +194,7 @@ void fak_init_theme(int upgrade)
     strcpy(th_alpha1, "");
     strcpy(th_alpha2, "");
     strcpy(th_background, "");
+    strcpy(th_icon_window, "");
 
     th_no_minus = FALSE;
 
@@ -208,6 +212,9 @@ void fak_init_theme(int upgrade)
     panels = 0;
     panel = 1;
 
+    panel_stop = 0;
+    panel_play = 0;
+
     /*
     if (upgrade) {
 	XpmFree(&alphaXPM);
@@ -225,11 +232,12 @@ int fak_load_theme(char *th, int upgrade)
     char key[256];
     char arguments[256];
     int button = FALSE;
-    unsigned int i,j;
+    unsigned int i;
     XWindowAttributes Attributes;
     int Ret;
     FILE *in;
 #ifdef MIXER
+    unsigned int j;
 struct {
     char name[MAX_LINE_NAME];
     int dev;
@@ -298,8 +306,7 @@ struct {
 			/* no more free buttons. We'll ignore the rest */
 			button = FALSE;
 		    }
-		}
-		if (key[0] == '}') {
+		} else if (key[0] == '}') {
 		    button = FALSE;
 		    
 		    /* update the pointers to msg, counter and tracknbr: */
@@ -324,7 +331,7 @@ struct {
 			break;
 		    }
 
-		    if (debug) {
+		    if (debug > 1) {
 			fprintf(stderr, "   Button %02d type: %02d commands: %02d %02d %02d arg: %02d\n", but_max, thdata[but_max].type, thdata[but_max].left, thdata[but_max].mid, thdata[but_max].right, thdata[but_max].arg);
 			fprintf(stderr, "   Geometry: %02dx%02d on panel %02d\n", thdata[but_max].x, thdata[but_max].y, thdata[but_max].panel);
 			fprintf(stderr, "   Pixmaps: [%s] and [%s]\n", thdata[but_max].xpm_file, thdata[but_max].altxpm_file);
@@ -343,8 +350,9 @@ struct {
 		    else if (strcmp(key, "background") == 0) strcpy(th_background, arguments);
 		    else if (strcmp(key, "icon_background") == 0) strcpy(th_icon_window, arguments);
 		    else if (strcmp(key, "panels") == 0) panels = atoi(arguments);
+		    else if (strcmp(key, "panel_stop") == 0) panel_stop = atoi(arguments);
+		    else if (strcmp(key, "panel_play") == 0) panel_play = atoi(arguments);
 		    else if (strcmp(key, "no_minus") == 0) th_no_minus = TRUE;
-		    else if (strcmp(key, "icon_window") == 0) th_no_icon_window = TRUE;
 		} else {
 
 		    /* button definition: */
@@ -353,33 +361,29 @@ struct {
 
 		    if (strcmp(key, "type") == 0) {
 			if (strcmp(arguments, "pixmap") == 0) thdata[but_max].type = FAK_PIXMAP;
-			if (strcmp(arguments, "counter") == 0) {
-			    thdata[but_max].type = FAK_COUNTER;
-			}
-			if (strcmp(arguments, "tracknumber") == 0) {
-			    thdata[but_max].type = FAK_TRACKNBR;
-			}
-			if (strcmp(arguments, "message") == 0) {
-			    thdata[but_max].type = FAK_MSG;
-			}
-			if (strcmp(arguments, "database") == 0) {
-			    thdata[but_max].type = FAK_DB;
-			}
-			if (strcmp(arguments, "progress_bar") == 0) thdata[but_max].type = FAK_CD_BAR;
-			if (strcmp(arguments, "vprogress_bar") == 0) thdata[but_max].type = FAK_VCD_BAR;
-			if (strcmp(arguments, "iprogress_bar") == 0) thdata[but_max].type = FAK_ICD_BAR;
-			if (strcmp(arguments, "volume_bar") == 0) thdata[but_max].type = FAK_VOL_BAR;
-			if (strcmp(arguments, "volume") == 0) thdata[but_max].type = FAK_VOL_BAR;
-			if (strcmp(arguments, "vvolume") == 0) thdata[but_max].type = FAK_VVOL_BAR;
-			if (strcmp(arguments, "vvolume_bar") == 0) thdata[but_max].type = FAK_VVOL_BAR;
-			if (strcmp(arguments, "ivolume") == 0) thdata[but_max].type = FAK_IVOL_BAR;
-			if (strcmp(arguments, "ivolume_bar") == 0) thdata[but_max].type = FAK_IVOL_BAR;
-			if (strcmp(arguments, "mixer_bar") == 0) thdata[but_max].type = FAK_MIXER_BAR;
-			if (strcmp(arguments, "mixer") == 0) thdata[but_max].type = FAK_MIXER_BAR;
-			if (strcmp(arguments, "vmixer_bar") == 0) thdata[but_max].type = FAK_VMIXER_BAR;
-			if (strcmp(arguments, "vmixer") == 0) thdata[but_max].type = FAK_VMIXER_BAR;
-			if (strcmp(arguments, "imixer_bar") == 0) thdata[but_max].type = FAK_IMIXER_BAR;
-			if (strcmp(arguments, "imixer") == 0) thdata[but_max].type = FAK_IMIXER_BAR;
+			else if (strcmp(arguments, "counter") == 0) thdata[but_max].type = FAK_COUNTER;
+			else if (strcmp(arguments, "tracknumber") == 0) thdata[but_max].type = FAK_TRACKNBR;
+			else if (strcmp(arguments, "message") == 0) thdata[but_max].type = FAK_MSG;
+			else if (strcmp(arguments, "database") == 0) thdata[but_max].type = FAK_DB;
+			else if (strcmp(arguments, "progress_bar") == 0) thdata[but_max].type = FAK_CD_BAR;
+			else if (strcmp(arguments, "vprogress_bar") == 0) thdata[but_max].type = FAK_VCD_BAR;
+			else if (strcmp(arguments, "iprogress_bar") == 0) thdata[but_max].type = FAK_ICD_BAR;
+			else if (strcmp(arguments, "pixmap_bar") == 0) thdata[but_max].type = FAK_CD_PIX;
+			else if (strcmp(arguments, "vpixmap_bar") == 0) thdata[but_max].type = FAK_VCD_PIX;
+			else if (strcmp(arguments, "volume_bar") == 0) thdata[but_max].type = FAK_VOL_BAR;
+			else if (strcmp(arguments, "volume") == 0) thdata[but_max].type = FAK_VOL_BAR;
+			else if (strcmp(arguments, "pixmap_volume") == 0) thdata[but_max].type = FAK_VOL_PIX;
+			else if (strcmp(arguments, "vpixmap_volume") == 0) thdata[but_max].type = FAK_VVOL_PIX;
+			else if (strcmp(arguments, "vvolume") == 0) thdata[but_max].type = FAK_VVOL_BAR;
+			else if (strcmp(arguments, "vvolume_bar") == 0) thdata[but_max].type = FAK_VVOL_BAR;
+			else if (strcmp(arguments, "ivolume") == 0) thdata[but_max].type = FAK_IVOL_BAR;
+			else if (strcmp(arguments, "ivolume_bar") == 0) thdata[but_max].type = FAK_IVOL_BAR;
+			else if (strcmp(arguments, "mixer_bar") == 0) thdata[but_max].type = FAK_MIXER_BAR;
+			else if (strcmp(arguments, "mixer") == 0) thdata[but_max].type = FAK_MIXER_BAR;
+			else if (strcmp(arguments, "vmixer_bar") == 0) thdata[but_max].type = FAK_VMIXER_BAR;
+			else if (strcmp(arguments, "vmixer") == 0) thdata[but_max].type = FAK_VMIXER_BAR;
+			else if (strcmp(arguments, "imixer_bar") == 0) thdata[but_max].type = FAK_IMIXER_BAR;
+			else if (strcmp(arguments, "imixer") == 0) thdata[but_max].type = FAK_IMIXER_BAR;
 		    }
 
 		    i = 0;
@@ -388,6 +392,8 @@ struct {
 			(strcmp(key, "mid") ==0) || 
 			(strcmp(key, "right") == 0)) {
 
+			/* --------------- available commands: ---------------- */
+
 			/* basic orders */
 
 			if (strcmp(arguments, "panel_switch") == 0) i = FAK_PANEL_SWITCH;
@@ -417,7 +423,7 @@ struct {
 
 			/* CD player */
 
-			if (strcmp(arguments, "play") == 0) i = FAK_CD_PLAY;
+			else if (strcmp(arguments, "play") == 0) i = FAK_CD_PLAY;
 			else if (strcmp(arguments, "pause") == 0) i = FAK_CD_PAUSE;
 			else if (strcmp(arguments, "stop") == 0) i = FAK_CD_STOP;
 			else if (strcmp(arguments, "eject") == 0) i = FAK_CD_EJECT;
@@ -448,7 +454,7 @@ struct {
 
 			/* mixer */
 
-			if (strcmp(arguments, "set") == 0) i = FAK_MIXER_SET;
+			else if (strcmp(arguments, "set") == 0) i = FAK_MIXER_SET;
 			else if (strcmp(arguments, "zero") == 0) i = FAK_MIXER_0;
 			else if (strcmp(arguments, "0") == 0) i = FAK_MIXER_0;
 			else if (strcmp(arguments, "50%") == 0) i = FAK_MIXER_50;
@@ -458,7 +464,7 @@ struct {
 			else if (strcmp(arguments, "100%") == 0) i = FAK_MIXER_100;
 			else if (strcmp(arguments, "100") == 0) i = FAK_MIXER_100;
 
-			/* which mouse button? */
+			/* ------------- which mouse button? --------------- */
 
 			if (strcmp(key, "left") == 0) thdata[but_max].left = i;
 			else if (strcmp(key, "middle") == 0) thdata[but_max].mid = i;
@@ -466,12 +472,12 @@ struct {
 			else if (strcmp(key, "right") == 0) thdata[but_max].right = i;
 		    }
 
-		    if (strcmp(key, "panel") == 0) thdata[but_max].panel = atoi(arguments);
-		    if (strcmp(key, "x") == 0) thdata[but_max].x = atoi(arguments);
-		    if (strcmp(key, "y") == 0) thdata[but_max].y = atoi(arguments);
-		    if (strcmp(key, "w") == 0) thdata[but_max].w = atoi(arguments);
-		    if (strcmp(key, "h") == 0) thdata[but_max].h = atoi(arguments);
-		    if (strcmp(key, "arg") == 0) {
+		    else if (strcmp(key, "panel") == 0) thdata[but_max].panel = atoi(arguments);
+		    else if (strcmp(key, "x") == 0) thdata[but_max].x = atoi(arguments);
+		    else if (strcmp(key, "y") == 0) thdata[but_max].y = atoi(arguments);
+		    else if (strcmp(key, "w") == 0) thdata[but_max].w = atoi(arguments);
+		    else if (strcmp(key, "h") == 0) thdata[but_max].h = atoi(arguments);
+		    else if (strcmp(key, "arg") == 0) {
 			thdata[but_max].arg = atoi(arguments);
 #ifdef MIXER
 			for(j = 0; j < SOUND_MIXER_NRDEVICES; j++) {
@@ -482,8 +488,8 @@ struct {
 			}
 #endif
 		    }
-		    if (strcmp(key, "pixmap") == 0) strcpy(thdata[but_max].xpm_file, arguments);
-		    if (strcmp(key, "alt") == 0) strcpy(thdata[but_max].altxpm_file, arguments);
+		    else if (strcmp(key, "pixmap") == 0) strcpy(thdata[but_max].xpm_file, arguments);
+		    else if (strcmp(key, "alt") == 0) strcpy(thdata[but_max].altxpm_file, arguments);
 		}
 	    }
 	}
@@ -496,7 +502,7 @@ struct {
 	    fprintf(stderr, "   URL:     %s\n", th_url);
 	    fprintf(stderr, "   Comment: %s\n", th_comment);
 	    fprintf(stderr, "   Stats:   %d panels, %d buttons\n", panels, but_max);
-	    fprintf(stderr, "   Display: counter: %d / msg: %d (%d cars) / db: %s / track: %d\n", but_counter, but_msg, thdata[but_msg].w, but_db, but_tracknbr);
+	    fprintf(stderr, "   Display: counter: %d / msg: %d (%d cars) / db: %d / track: %d\n", but_counter, but_msg, thdata[but_msg].w, but_db, but_tracknbr);
 	    if (th_no_icon_window) 	    fprintf(stderr, "   Using separate icon definition, background = %s\n", th_icon_window);
 	    fprintf(stderr, "-> Loading basic pixmap files... ");
 	}
@@ -531,18 +537,18 @@ struct {
 	if (debug) fprintf(stderr, "\n-> Loading buttons pixmaps... ");
 	for (i = 1; i <= but_max; i++) {
 	    if (strlen(thdata[i].xpm_file) > 0) {
-		if (debug) fprintf(stderr, "%d ", i);
+		if (debug > 1) fprintf(stderr, "%d ", i);
 		fak_validate_pixmap(txt, thdata[i].xpm_file);
 		thdata[i].xpm.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
 		Ret = XpmReadFileToPixmap(Disp, Root, txt, &thdata[i].xpm.pixmap, &thdata[i].xpm.mask, &thdata[i].xpm.attributes);
-		if ((Ret != XpmSuccess) && (debug)) fprintf(stderr, "*!* ");
+		if ((Ret != XpmSuccess) && (debug > 1)) fprintf(stderr, "*!* ");
 	    }
 	    if (strlen(thdata[i].altxpm_file) > 0) {
-		if (debug) fprintf(stderr, "a ");
+		if (debug > 1) fprintf(stderr, "a ");
 		fak_validate_pixmap(txt, thdata[i].altxpm_file);
 		thdata[i].xpm.attributes.valuemask |= (XpmReturnPixels | XpmReturnExtensions);
 		Ret = XpmReadFileToPixmap(Disp, Root, txt, &thdata[i].altxpm.pixmap, &thdata[i].altxpm.mask, &thdata[i].altxpm.attributes);
-		if ((Ret != XpmSuccess) && (debug)) fprintf(stderr, "*!* ");
+		if ((Ret != XpmSuccess) && (debug > 1)) fprintf(stderr, "*!* ");
 	    }
 	}
 
@@ -1041,6 +1047,10 @@ void fak_redraw()
     int offset;
     DIR *dir_fd;
     struct dirent *dir_pt;
+    unsigned int fx;
+    unsigned int fy;
+    unsigned int fw;
+    unsigned int fh;
 
     /* ============================================================== */
     /* ============================================================== */
@@ -1056,6 +1066,11 @@ void fak_redraw()
 	if ((cur_cdmode == WM_CDM_PLAYING) || (wanna_play)) wm_cd_status();
     }
 
+    /* the panel auto-switch mode: */
+
+    if (((cur_cdmode == WM_CDM_STOPPED) || (cur_cdmode == WM_CDM_EJECTED)) && (panel_stop > 0)) panel = panel_stop;
+    if (((cur_cdmode == WM_CDM_PLAYING) || (cur_cdmode == WM_CDM_PAUSED)) && (panel_play > 0)) panel = panel_play;
+
     /* ===================================================================
        Auto-Repeat mode: at then end of the CD, play again the first track
        =================================================================== */
@@ -1077,58 +1092,6 @@ void fak_redraw()
 	} 
     }
 
-    /* ================= */
-    /* The auto fade out */
-    /* ================= */
-
-    if ((cur_cdmode == WM_CDM_PLAYING) && (fade_out)) {
-	if (!fade_ok) {
-	    fade_ok = 1;
-	    return;
-	} else {
-	    unmuted_volume = volume ;
-	    while (volume > min_volume) {
-		volume = volume - fade_step;
-		cd_volume(volume, 10, max_volume);
-		usleep(dodo);
-	    }
-	    fade_out = 0;
-	    fade_ok = 0;
-	    cd_control(PAUSE);
-	    old_track = 0;
-	    volume = unmuted_volume;
-	    cd_volume(volume, 10, max_volume);
-	}
-    }
-
-    /* ================= */
-    /* The auto fade in: */
-    /* ================= */
-
-    if ((cur_cdmode == WM_CDM_PAUSED) && (fade_out)){
-	if (!fade_ok) {
-	    fade_ok = 1;
-	    return;
-	} else {
-	    unmuted_volume = volume;
-	    volume = min_volume;
-	    cd_volume(volume, 10, max_volume);
-	    wm_cd_status();
-	    usleep(dodo * 5);
-	    cd_control(PAUSE);
-	    usleep(dodo * 5);
-	    while (volume < max_volume) {
-		volume = volume + fade_step;
-		cd_volume(volume, 10, max_volume);
-		usleep(dodo);
-	    }
-	    fade_out = 0;
-	    fade_ok = 0;
-	    volume = unmuted_volume;
-	    cd_volume(volume, 10, max_volume);
-	}
-    }
-
     /* ======================================================= */
     /* the next track handling. We have to skip 'avoid' tracks */
     /* ======================================================= */
@@ -1136,7 +1099,7 @@ void fak_redraw()
     if ((cur_cdmode != WM_CDM_EJECTED) && (! ignore_avoid)) {
 	if (cur_ntracks > 1) { /* only if there are more than ONE track */
 	    if (cur_track != old_track) {
-		if (debug) fprintf(stderr, "-> Track change\n");
+		if (debug) fprintf(stderr, "-> Track change (current = %d, old = %d)\n", cur_track, old_track);
 		redraw = TRUE;
 		i = cur_track - 1;
 		while ((i <= cur_ntracks) && (cd->trk[i].avoid == 1)) {
@@ -1280,6 +1243,7 @@ void fak_redraw()
 			}
 		    }
 		}
+
 	    } else if (thdata[i].type == FAK_ICD_BAR) {
 		if ( (cur_cdmode != WM_CDM_STOPPED) && (cur_cdmode != WM_CDM_EJECTED) ) {
 		    if ((time_mode == 2) || (time_mode == 3)) {
@@ -1322,6 +1286,7 @@ void fak_redraw()
 			}
 		    }
 		}
+
 	    } else if (thdata[i].type == FAK_CD_BAR) {
 		if ( (cur_cdmode != WM_CDM_STOPPED) && (cur_cdmode != WM_CDM_EJECTED) ) {
 		    if ((time_mode == 2) || (time_mode == 3)) {
@@ -1348,6 +1313,102 @@ void fak_redraw()
 			}
 		    }
 		}
+
+	    } else if (thdata[i].type == FAK_VCD_PIX) { /************** vertical pixmap slider *****************/
+		if ((cur_cdmode != WM_CDM_STOPPED) && (cur_cdmode != WM_CDM_EJECTED) && (cur_cdlen > 0)) {
+
+		    /* erase the old position : */
+
+		    if (thdata[i].ox > 0) {
+			XCopyArea(Disp, thdata[i].xpm.pixmap, Win, WinGC, 
+				  0, thdata[i].oy, 
+				  thdata[i].altxpm.attributes.width, thdata[i].altxpm.attributes.height,
+				  thdata[i].x, 
+				  thdata[i].oy + thdata[i].y);
+			
+			if (!th_no_icon_window) {
+			    XCopyArea(Disp, thdata[i].xpm.pixmap, Iconwin, WinGC, 
+				      0, thdata[i].oy,
+				      thdata[i].altxpm.attributes.width, thdata[i].altxpm.attributes.height,
+				      thdata[i].x, 
+				      thdata[i].oy + thdata[i].y);
+			}
+		    }
+
+		    /* compute the new geometry: */
+
+		    if ((time_mode == 2) || (time_mode == 3)) fx = (int)((float)cur_pos_abs / (float)cur_cdlen * (float)(thdata[i].xpm.attributes.width - thdata[i].altxpm.attributes.width));
+		    else fx = (int)((float)cur_pos_rel / (float)cur_tracklen * (float)(thdata[i].xpm.attributes.width - thdata[i].altxpm.attributes.width));
+
+		    /* ugly, need to CHANGE THIS!!!!! */
+		    if (fx < 1) fx = 1;
+
+		    /* and show it: */
+
+		    XCopyArea(Disp, thdata[i].altxpm.pixmap, Win, WinGC, 
+			      0, 0, 
+			      thdata[i].altxpm.attributes.width, thdata[i].altxpm.attributes.height,
+			      thdata[i].x, 
+			      thdata[i].y + fx);
+
+		    if (!th_no_icon_window) {
+			XCopyArea(Disp, thdata[i].altxpm.pixmap, Iconwin, WinGC, 
+				  0, 0, 
+				  thdata[i].altxpm.attributes.width, thdata[i].altxpm.attributes.height,
+				  thdata[i].x, 
+				  thdata[i].y + fx);
+		    }
+
+		    /* finaly, save it! */
+		    thdata[i].oy = fx;
+		}
+	    } else if (thdata[i].type == FAK_CD_PIX) { /**************** horizontal pixmap slider *****************/
+		if ((cur_cdmode != WM_CDM_STOPPED) && (cur_cdmode != WM_CDM_EJECTED) && (cur_cdlen > 0)) {
+		    /* erase the old position : */
+
+		    if (thdata[i].ox > 0) {
+			XCopyArea(Disp, thdata[i].xpm.pixmap, Win, WinGC, 
+				  thdata[i].ox, 0, 
+				  thdata[i].altxpm.attributes.width, thdata[i].altxpm.attributes.height,
+				  thdata[i].ox + thdata[i].x, 
+				  thdata[i].y);
+			
+			if (!th_no_icon_window) {
+			    XCopyArea(Disp, thdata[i].xpm.pixmap, Iconwin, WinGC, 
+				      thdata[i].ox, 0, 
+				      thdata[i].altxpm.attributes.width, thdata[i].altxpm.attributes.height,
+				      thdata[i].ox + thdata[i].x, 
+				      thdata[i].y);
+			}
+		    }
+
+		    /* compute the new geometry: */
+
+		    if ((time_mode == 2) || (time_mode == 3)) fx = (int)((float)cur_pos_abs / (float)cur_cdlen * (float)(thdata[i].xpm.attributes.height - thdata[i].altxpm.attributes.height));
+		    else fx = (int)((float)cur_pos_rel / (float)cur_tracklen * (float)(thdata[i].xpm.attributes.height - thdata[i].altxpm.attributes.height));
+
+		    /* ugly, need to CHANGE THIS!!!!! */
+		    if (fx < 1) fx = 1;
+
+		    /* and show it: */
+
+		    XCopyArea(Disp, thdata[i].altxpm.pixmap, Win, WinGC, 
+			      0, 0, 
+			      thdata[i].altxpm.attributes.width, thdata[i].altxpm.attributes.height,
+			      thdata[i].x + fx, 
+			      thdata[i].y);
+
+		    if (!th_no_icon_window) {
+			XCopyArea(Disp, thdata[i].altxpm.pixmap, Iconwin, WinGC, 
+				  0, 0, 
+				  thdata[i].altxpm.attributes.width, thdata[i].altxpm.attributes.height,
+				  thdata[i].x + fx, 
+				  thdata[i].y);
+		    }
+
+		    /* finaly, save it! */
+		    thdata[i].ox = fx;
+		}
 	    } else if (thdata[i].type == FAK_VOL_BAR) {
 		if ( (cur_cdmode != WM_CDM_STOPPED) && (cur_cdmode != WM_CDM_EJECTED) ) {
 		    XCopyArea(Disp, thdata[i].xpm.pixmap, Win, WinGC, 0, 0, 
@@ -1359,6 +1420,53 @@ void fak_redraw()
 				  thdata[i].xpm.attributes.height, thdata[i].x, thdata[i].y);
 		    }
 		}
+	    } else if (thdata[i].type == FAK_VOL_PIX) {
+		if ((cur_cdmode != WM_CDM_STOPPED) && (cur_cdmode != WM_CDM_EJECTED)) {
+
+		    /* first erase the old position : */
+
+		    if (thdata[i].ox > 0) {
+			XCopyArea(Disp, thdata[i].xpm.pixmap, Win, WinGC, 
+				  thdata[i].ox, 0, 
+				  thdata[i].altxpm.attributes.width, thdata[i].altxpm.attributes.height,
+				  thdata[i].ox + thdata[i].x, 
+				  thdata[i].y);
+			
+			if (!th_no_icon_window) {
+			    XCopyArea(Disp, thdata[i].xpm.pixmap, Iconwin, WinGC, 
+				      thdata[i].ox, 0, 
+				      thdata[i].altxpm.attributes.width, thdata[i].altxpm.attributes.height,
+				      thdata[i].ox + thdata[i].x, 
+				      thdata[i].y);
+			}
+		    }
+
+		    /* compute the new geometry: */
+
+		    fx = (int)((float)volume / (float)max_volume * (float)(thdata[i].xpm.attributes.width - thdata[i].altxpm.attributes.width));
+
+		    /* ugly, need to CHANGE THIS!!!!! */
+		    if (fx < 1) fx = 1;
+
+		    /* and show it: */
+
+		    XCopyArea(Disp, thdata[i].altxpm.pixmap, Win, WinGC, 
+			      0, 0, 
+			      thdata[i].altxpm.attributes.width, thdata[i].altxpm.attributes.height,
+			      thdata[i].x + fx, 
+			      thdata[i].y);
+
+		    if (!th_no_icon_window) {
+			XCopyArea(Disp, thdata[i].altxpm.pixmap, Iconwin, WinGC, 
+				  0, 0, 
+				  thdata[i].altxpm.attributes.width, thdata[i].altxpm.attributes.height,
+				  thdata[i].x + fx, 
+				  thdata[i].y);
+		    }
+
+		    /* finaly, save it! */
+		    thdata[i].ox = fx;
+		}
 	    } else if (thdata[i].type == FAK_VVOL_BAR) {
 		if ( (cur_cdmode != WM_CDM_STOPPED) && (cur_cdmode != WM_CDM_EJECTED) ) {
 		    XCopyArea(Disp, thdata[i].xpm.pixmap, Win, WinGC, 0, 0, 
@@ -1484,8 +1592,8 @@ void fak_redraw()
     /* no CD? no counters! */
 
     if (cur_cdmode == WM_CDM_EJECTED) {
-	 if (!th_no_minus) fak_text("AScd", COUNTER_PANEL, 1, FALSE);
-	 else fak_text("AScd", COUNTER_PANEL, 0, FALSE);
+	if (!th_no_minus) fak_text("AScd", COUNTER_PANEL, 1, FALSE);
+	else fak_text("AScd", COUNTER_PANEL, 0, FALSE);
 	fak_text("NO CD", MSG_PANEL, 1, TRUE);
         if (debug) fprintf(stderr, "-> No CD. Leaving redraw routine\n");
 	return;
@@ -1542,12 +1650,14 @@ void fak_redraw()
 	} else {
 	    sprintf(cdtime, "%02d", cur_ntracks);
 	}
-	fak_text(cdtime, TRACK_PANEL, 0, TRUE);
+        if ((thdata[but_tracknbr].panel == panel) || (thdata[but_tracknbr].panel == 0))
+	    fak_text(cdtime, TRACK_PANEL, 0, TRUE);
     } else {
 	if (time(NULL) - selectors_timeout <= 3) {
 	    sprintf(cdtime, "%02d", fast_track);
 	    fak_text("TRACK", COUNTER_PANEL, 0, TRUE);
-	    fak_text(cdtime, TRACK_PANEL, 0, FALSE);
+	    if ((thdata[but_tracknbr].panel == panel) || (thdata[but_tracknbr].panel == 0))
+		fak_text(cdtime, TRACK_PANEL, 0, FALSE);
 	    return;
 	} else {
 	    selectors_timeout = 0;
@@ -1608,5 +1718,60 @@ void fak_redraw()
     if (th_no_minus) fak_text(cdtime, 0, 0, FALSE);
     else fak_text(cdtime, 0, 1, FALSE);
 
+    /* ================= */
+    /* The auto fade out */
+    /* ================= */
+
+    if ((cur_cdmode == WM_CDM_PLAYING) && (fade_out)) {
+	if (!fade_ok) {
+	    fade_ok = 1;
+	    return;
+	} else {
+	    unmuted_volume = volume ;
+	    while (volume > min_volume) {
+		volume = volume - fade_step;
+		cd_volume(volume, 10, max_volume);
+		usleep(dodo);
+	    }
+	    fade_out = 0;
+	    fade_ok = 0;
+	    cd_control(PAUSE);
+	    old_track = 0;
+	    volume = unmuted_volume;
+	    cd_volume(volume, 10, max_volume);
+	}
+    }
+
+    /* ================= */
+    /* The auto fade in: */
+    /* ================= */
+
+    if ((cur_cdmode == WM_CDM_PAUSED) && (fade_out)){
+	if (!fade_ok) {
+	    fade_ok = 1;
+	    return;
+	} else {
+	    unmuted_volume = volume;
+	    volume = min_volume;
+	    cd_volume(volume, 10, max_volume);
+	    wm_cd_status();
+	    usleep(dodo * 5);
+	    cd_control(PAUSE);
+	    usleep(dodo * 5);
+	    while (volume < max_volume) {
+		volume = volume + fade_step;
+		cd_volume(volume, 10, max_volume);
+		usleep(dodo);
+	    }
+	    fade_out = 0;
+	    fade_ok = 0;
+	    volume = unmuted_volume;
+	    cd_volume(volume, 10, max_volume);
+	}
+    }
+
+    /* end of redraw routine */
+
+    old_track = cur_track;
     if (debug) fprintf(stderr, "-> End of global redraw. Leaving redraw routine\n");
 }
