@@ -1,5 +1,5 @@
 /*
- * $Id: cdrom.c,v 1.8 1999/03/07 08:36:39 dirk Exp $
+ * $Id: cdrom.c,v 1.10 1999/05/05 16:34:19 dirk Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -27,7 +27,7 @@
  * platform- or drive-dependent code here.
  */
 
-static char cdrom_id[] = "$Id: cdrom.c,v 1.8 1999/03/07 08:36:39 dirk Exp $";
+static char cdrom_id[] = "$Id: cdrom.c,v 1.10 1999/05/05 16:34:19 dirk Exp $";
 
 #include <errno.h>
 #include <stdio.h>
@@ -39,6 +39,7 @@ static char cdrom_id[] = "$Id: cdrom.c,v 1.8 1999/03/07 08:36:39 dirk Exp $";
 
 #include "include/wm_config.h"
 #include "include/wm_struct.h"
+#include "include/wm_cddb.h"
 #include "include/wm_cdrom.h"
 #include "include/wm_database.h"
 #include "include/wm_platform.h"
@@ -253,7 +254,8 @@ read_toc()
 	}
 
 	thiscd.length = thiscd.trk[thiscd.ntracks].length;
-
+        thiscd.cddbid = cddb_discid(drive);
+        
 	return (&thiscd);
 }
 
@@ -653,7 +655,7 @@ wm_cd_eject( void )
 
 int wm_cd_closetray(void)
 {
-    return((drive.closetray)(&drive) ? 0 : wm_cd_status()==2 ? 1 : 0);
+	return((drive.closetray)(&drive) ? 0 : wm_cd_status()==2 ? 1 : 0);
 } /* wm_cd_closetray() */
 
 /*
@@ -729,7 +731,7 @@ find_trkind( int track, int index, int start )
  * "max" is the maximum value of the volume knob.
  */
 int
-read_initial_volume( int max )
+wm_cd_read_initial_volume( int max )
 {
 	int	left, right;
 
@@ -760,7 +762,7 @@ read_initial_volume( int max )
 
 		return (left);
 	}
-} /* read_initial_volume() */
+} /* wm_cd_read_initial_volume() */
 
 /*
  * Prototype wm_drive structure, with generic functions.  The generic functions
