@@ -1,5 +1,5 @@
 /*
- * $Id: database.c,v 1.7 1999/05/05 16:34:20 dirk Exp $
+ * $Id: database.c,v 1.8 1999/05/28 03:35:54 dirk Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -27,7 +27,7 @@
  * obviously it won't contain track titles just after a CD is inserted.)
  */
 
-static char database_id[] = "$Id: database.c,v 1.7 1999/05/05 16:34:20 dirk Exp $";
+static char database_id[] = "$Id: database.c,v 1.8 1999/05/28 03:35:54 dirk Exp $";
 
 #define RCFILE "/.workmanrc"
 #define DBFILE "/.workmandb"
@@ -1229,16 +1229,17 @@ save_globals(FILE *fp)
 		sprintf(temp, "cddbprotocol ");
 		switch(cddb.protocol)
 		{
-		 case 1: // cddbp
+		 case 1: /* cddbp */
 		    sprintf(temp + strlen(temp), "cddbp\n");
 		    break;
-		 case 2: // http
+		 case 2: /* http */
 		    sprintf(temp + strlen(temp), "http\n");
 		    break;
-		 case 3: // proxy
+		 case 3: /* proxy */
 		    sprintf(temp + strlen(temp), "proxy\n");
 		    break;
 		 default:
+		    break;
 		}
 		wm_strmcat(&globes, temp);
 	    
