@@ -1,5 +1,5 @@
 /*
- * $Id: plat_linux.c,v 1.7 1999/03/07 08:36:40 dirk Exp $
+ * $Id: plat_linux.c,v 1.8 1999/06/17 06:48:03 dirk Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -27,7 +27,7 @@
 
 #ifdef linux
 /* Id for ident command */
-static char plat_linux_id[] = "$Id: plat_linux.c,v 1.7 1999/03/07 08:36:40 dirk Exp $";
+static char plat_linux_id[] = "$Id: plat_linux.c,v 1.8 1999/06/17 06:48:03 dirk Exp $";
 
 #include <errno.h>
 #include <stdio.h>
@@ -44,8 +44,6 @@ static char plat_linux_id[] = "$Id: plat_linux.c,v 1.7 1999/03/07 08:36:40 dirk
 
 #include "include/wm_config.h"
 
-#undef OSS_SUPPORT
-
 #if defined(BSD_MOUNTTEST)
   #include <mntent.h>
 #else
@@ -809,7 +807,7 @@ wmcd_open( struct wm_drive *d )
 /* Hack proposed by Carey Evans, introduced by Debian maintainer :
  * treat EIO like ENXIO since some Linux drives do never return ENXIO
  */
-		else if ((errno != ENXIO) && (errno != EIO))
+		else if ((errno != ENXIO) && (errno != EIO) && (errno != ENOMEDIUM))
 		{
 			perror(cd_device);
 			exit(1);
