@@ -1,5 +1,5 @@
 /*
- * $Id: plat_sun.c,v 1.8 1999/05/05 16:09:49 dirk Exp $
+ * $Id: plat_sun.c,v 1.9 1999/05/28 03:35:54 dirk Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -26,7 +26,7 @@
  */
 
 #ifdef sun
-static char plat_sun_id[] = "$Id: plat_sun.c,v 1.8 1999/05/05 16:09:49 dirk Exp $";
+static char plat_sun_id[] = "$Id: plat_sun.c,v 1.9 1999/05/28 03:35:54 dirk Exp $";
 
 #include <errno.h>
 #include <stdio.h>
@@ -94,7 +94,7 @@ static struct wm_drive *thecd;
 
 static void thawme(int sig)
 {
-	change_mode(NULL, STOPPED, NULL);
+	change_mode(NULL, WM_CDM_STOPPED, NULL);
 	codec_init();
 	if( thecd )
 	  gen_set_volume(thecd, last_left, last_right);
@@ -455,7 +455,7 @@ gen_get_drive_status( struct wm_drive *d,
 
 	switch (sc.cdsc_audiostatus) {
 	case CDROM_AUDIO_PLAY:
-		*mode = PLAYING;
+		*mode = WM_CDM_PLAYING;
 		*track = sc.cdsc_trk;
 		*index = sc.cdsc_ind;
 		*pos = sc.cdsc_absaddr.msf.minute * 60 * 75 +
@@ -556,12 +556,12 @@ gen_pause( struct wm_drive *d )
 {
 	if (cdda_slave > -1)
 	{
-		int	dummy, mode = PLAYING;
+		int	dummy, mode = WM_CDM_PLAYING;
 
 		write(cdda_slave, "S", 1);
 		get_ack(cdda_slave);
-/*		while (mode != PAUSED)
-			gen_get_drive_status(d, PAUSED, &mode, &dummy, &dummy,
+/*		while (mode != WM_CDM_PAUSED)
+			gen_get_drive_status(d, WM_CDM_PAUSED, &mode, &dummy, &dummy,
 						&dummy);
 */
 		return (0);
